netapp_ontap.models.snapmirror_destination_creation_storage_service API documentation
Description: Copyright &copy; 2020 NetApp Inc. All rights reserved.

# Module `netapp_ontap.models.snapmirror_destination_creation_storage_service`

Copyright © 2020 NetApp Inc. All rights reserved.

## Classes

`class SnapmirrorDestinationCreationStorageServiceSchema (*, only: typing.Union = None, exclude: typing.Union = (), many: bool = False, context: typing.Dict = None, load_only: typing.Union = (), dump_only: typing.Union = (), partial: typing.Union = False, unknown: str = None)`

  The fields of the SnapmirrorDestinationCreationStorageService object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC

  ### Class variables

  `enabled GET POST PATCH`

    This property indicates whether to create the destination endpoint using storage service.

  `enforce_performance GET POST PATCH`

    Optional property to enforce storage service performance on the destination endpoint. This property is applicable to FlexVol volume, FlexGroup volume, and Consistency Group endpoints.

  `name GET POST PATCH`

    Optional property to specify the storage service name for the destination endpoint. This property is considered when the property "create_destination.storage_service.enabled" is set to "true". When the property "create_destination.storage_service.enabled" is set to "true" and the "create_destination.storage_service.name" for the endpoint is not specified, then ONTAP selects the highest storage service available on the cluster to provision the destination endpoint. This property is applicable to FlexVol volume, FlexGroup volume, and Consistency Group endpoints.

    Valid choices:

    - extreme
    - performance
    - value